'''Simple data loader module.

Loads data files from the "data" directory shipped with a game.

Enhancing this to handle caching etc. is left as an exercise for the reader.
'''

import os
import pygame

data_py = os.path.abspath(os.path.dirname(__file__))
data_dir = os.path.normpath(os.path.join(data_py, '..', 'data'))

def filepath(filename):
    '''Determine the path to a file in the data directory.
    '''
    return os.path.join(data_dir, filename)

def loadimage(filename,alpha=True,cache={}):
    if filename in cache:
        return cache[filename]
    path = filepath(filename)
    if alpha:
        img = pygame.image.load(path).convert_alpha()
    else:
        img = pygame.image.load(path).convert()
    cache[filename] = img
    return img

def loadfont(filename,size,cache={}):
    pygame.font.init()
    if (filename,size) in cache:
        return cache[(filename,size)]
    path = filepath('fonts/'+filename)
    font = pygame.font.Font(path,size)
    cache[(filename,size)] = font
    return font

def loadsound(filename,cache={}):
    if filename in cache:
        return cache[filename]
    path = filepath('sounds/'+filename)
    sound = pygame.mixer.Sound(path)
    cache[filename] = sound
    return sound

def load(filename, mode='rb'):
    '''Open a file in the data directory.

    "mode" is passed as the second arg to open().
    '''
    return open(os.path.join(data_dir, filename), mode)

